==> kadu_0.5.0.orig.tar.gz: mail/translations/mail_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Mail</source>
        <translation>Poczta</translation>
    </message>
    <message>
        <source>Interval in seconds</source>
        <translation>Odstęp pomiędzy sprawdzaniem </translation>
    </message>
    <message>
        <source>Message format</source>
        <translation>Format powiadomnienia </translation>
    </message>
    <message>
        <source>Run mail client</source>
        <translation>Uruchom klienta poczty</translation>
    </message>
    <message>
        <source>Mail client</source>
        <translation>Klient poczty </translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Kolory</translation>
    </message>
    <message>
        <source>Font color</source>
        <translation>Kolor czcionki</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Kolor tła</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Wybierz</translation>
    </message>
    <message>
        <source>Hint timeout</source>
        <translation>Czas pokazywania dymków </translation>
    </message>
    <message>
        <source>Maildir</source>
        <translation>Katalog Maildir</translation>
    </message>
    <message>
        <source>Maildir path</source>
        <translation>Ścieżka do katalogu Maildir </translation>
    </message>
    <message>
        <source>Checking options</source>
        <translation>Opcje sprawdzania</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation>Konta</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>%n new messages
%t total on server
%s total size
%a account</source>
        <translation>%n nowe wiadomości
%t wszystki na serwerze
%s rozmiar wszystkich na serwerze
%a konto</translation>
    </message>
    <message>
        <source>Check mail in local Maildir</source>
        <translation>Sprawdzaj pocztę w katalogu lokalnym</translation>
    </message>
</context>
<context>
    <name>AccountDialog</name>
    <message>
        <source>Account edit</source>
        <translation>Edycja konta</translation>
    </message>
    <message>
        <source>Accont name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Server address</source>
        <translation>Adres serwera</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Name of account must be set</source>
        <translation>Nazwa konta musi być ustawiona</translation>
    </message>
</context>
<context>
    <name>Mail</name>
    <message>
        <source>Could not run your mail client check your setting</source>
        <translation>Nie moge uruchomić klienta poczty sprawdź swoje ustawienia</translation>
    </message>
    <message>
        <source>Maildir not found!</source>
        <translation>Katalog Maildir nie istnieje!</translation>
    </message>
    <message>
        <source>Maildir is not readable!</source>
        <translation>Nie mogę odczytać katalogu Maildir!</translation>
    </message>
    <message>
        <source>You have %n new mail(s) on %a and total you have %t mail(s) witch total size %s</source>
        <translation>Masz %n nowych wiadomości na %a a razem masz %t wiadomości zajmują one %s</translation>
    </message>
</context>
<context>
    <name>Pop3Proto</name>
    <message>
        <source>Cannot connect to mail server : %0 on account %1</source>
        <translation>Nie mogę się połączyć z serwerem poczty %0 na koncie %1</translation>
    </message>
    <message>
        <source>Cannot connect to mail server on account %1</source>
        <translation>Nie mogę się połączyć z serwerem poczty na koncie %1</translation>
    </message>
    <message>
        <source>Bad login to POP server on %0</source>
        <translation>Zły login do serwera POP na %0</translation>
    </message>
    <message>
        <source>Bad password to POP server on %0</source>
        <translation>Złe hasło do serwera POP na %0</translation>
    </message>
    <message>
        <source>Cannot check mail</source>
        <translation>Czas pokazywania dymków </translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.orig.tar.gz: mail/translations/mail_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Mail</source>
        <translation>Poczta</translation>
    </message>
    <message>
        <source>Interval in seconds</source>
        <translation>Odstęp pomiędzy sprawdzaniem </translation>
    </message>
    <message>
        <source>Message format</source>
        <translation>Format powiadomnienia </translation>
    </message>
    <message>
        <source>Run mail client</source>
        <translation>Uruchom klienta poczty</translation>
    </message>
    <message>
        <source>Mail client</source>
        <translation>Klient poczty </translation>
    </message>
    <message>
        <source>Maildir</source>
        <translation>Katalog Maildir</translation>
    </message>
    <message>
        <source>Maildir path: </source>
        <translation>Ścieżka do katalogu Maildir: </translation>
    </message>
    <message>
        <source>Checking options</source>
        <translation>Opcje sprawdzania</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation>Konta</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>%n new messages
%t total on server
%s total size
%a account</source>
        <translation>%n nowe wiadomości
%t wszystki na serwerze
%s rozmiar wszystkich na serwerze
%a konto</translation>
    </message>
    <message>
        <source>Check mail in local Maildir</source>
        <translation>Sprawdzaj pocztę w katalogu lokalnym</translation>
    </message>
</context>
<context>
    <name>AccountDialog</name>
    <message>
        <source>Account edit</source>
        <translation>Edycja konta</translation>
    </message>
    <message>
        <source>Account name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Server address</source>
        <translation>Adres serwera</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Name of account must be set</source>
        <translation>Nazwa konta musi być ustawiona</translation>
    </message>
    <message>
        <source>No encryption</source>
        <translation>Nie szyfrowane</translation>
    </message>
    <message>
        <source>Connection type</source>
        <translation>Typ połączenia</translation>
    </message>
</context>
<context>
    <name>Mail</name>
    <message>
        <source>Could not run your mail client check your setting</source>
        <translation>Nie moge uruchomić klienta poczty sprawdź swoje ustawienia</translation>
    </message>
    <message>
        <source>Maildir not found!</source>
        <translation>Katalog Maildir nie istnieje!</translation>
    </message>
    <message>
        <source>Maildir is not readable!</source>
        <translation>Nie mogę odczytać katalogu Maildir!</translation>
    </message>
    <message>
        <source>You have %n new mail(s) on %a and total you have %t mail(s) witch total size %s</source>
        <translation>Masz %n nowych wiadomości na %a a razem masz %t wiadomości zajmują one %s</translation>
    </message>
</context>
<context>
    <name>Pop3Proto</name>
    <message>
        <source>Cannot connect to mail server : %0 on account %1</source>
        <translation>Nie mogę się połączyć z serwerem poczty %0 na koncie %1</translation>
    </message>
    <message>
        <source>Cannot connect to mail server on account %1</source>
        <translation>Nie mogę się połączyć z serwerem poczty na koncie %1</translation>
    </message>
    <message>
        <source>Bad login to POP server on %0</source>
        <translation>Zły login do serwera POP na %0</translation>
    </message>
    <message>
        <source>Bad password to POP server on %0</source>
        <translation>Złe hasło do serwera POP na %0</translation>
    </message>
    <message>
        <source>Cannot check mail</source>
        <translation>Czas pokazywania dymków </translation>
    </message>
</context>
</TS>
